/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * @file src/applications/afs/gtkui/helper.c
 * @author Igor Wronsky
 *
 * This file contains some GUI helper functions
 **/

#include "config.h"
#include <gtk/gtk.h>

#include "util/logging.h"

#define HELPER_DEBUG NO

/**
 * Callback for handling "delete_event": close the window 
 **/
gint deleteEvent(GtkWidget * widget,
		 GdkEvent * event,
		 gpointer data) {
#if DEBUG_HELPER
  LOG(LOG_DEBUG, 
      "DEBUG: deleteEvent\n");
#endif
  return FALSE;
}

/**
 * A callback to destroy any widget given as second argument
 **/
void destroyWidget(GtkWidget * dummy, 
		   GtkWidget * widget) {
#if DEBUG_HELPER
  LOG(LOG_DEBUG, 
      "DEBUG: destroyWidget %d\n", 
      widget);
#endif
  gtk_widget_destroy(widget);
}

/** 
 * Displays an informative message to the user 
 **/
void guiMessage(const char * format, ...) {
  va_list args;
  gchar *note;
  GtkWidget * window;
  GtkWidget * label;
  GtkWidget * box;
  GtkWidget * button;

  va_start(args, format);
  note = g_strdup_vprintf(format, args);
  va_end(args);

  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width(GTK_CONTAINER(window), 10);
  gtk_window_set_policy(GTK_WINDOW(window),
			FALSE,
			FALSE,
			TRUE);
  gtk_window_set_position(GTK_WINDOW(window),
			  GTK_WIN_POS_MOUSE);
  gtk_window_set_title(GTK_WINDOW(window), 
		       "Note");
  gtk_signal_connect(GTK_OBJECT(window), 
		     "delete_event",
		     GTK_SIGNAL_FUNC(deleteEvent), 
		     NULL);

  box = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(window), 
		    box);
  gtk_widget_show(box);

  label = gtk_label_new(note);
  gtk_box_pack_start(GTK_BOX(box),
		     label,
		     FALSE,
		     FALSE,
		     0);
  gtk_widget_show(label);
  
  button = gtk_button_new_with_label("Ok");
  gtk_signal_connect(GTK_OBJECT (button),
		      "clicked",
		      GTK_SIGNAL_FUNC(destroyWidget),
		     window);
  gtk_box_pack_start(GTK_BOX(box),button,FALSE,FALSE,0);
  gtk_widget_show(button);
  
  gtk_widget_show(window);
}

/* end of helper.c */

